.periodic-table-entry{border:1px solid;border-color:#c77;border-radius:3px;width:38px;height:38px;display:table-cell;text-align:center;vertical-align:middle;background-color:#faa}.periodic-table-disabled{border-radius:3px;width:38px;height:38px;display:table-cell;text-align:center;vertical-align:middle;background-color:#999}.periodic-table-empty{border:0px;width:38px;height:38px;display:table-cell;text-align:center;vertical-align:middle}.periodic-table-row{display:table-row}.periodic-table-body{display:table;border-spacing:4px;margin:10px}.periodic-table-entry:hover{background-color:#c77;transform:scale(1.4)}.periodic-table-entry.elementOn{background-color:#aaf;border:1px solid #7777cc;border-radius:4px}.periodic-table-entry.elementOn:hover{background-color:#77c;border:1px solid #7777cc;border-radius:4px}.noselect{-webkit-touch-callout:none;-webkit-user-select:none;-khtml-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}
